@@ -15,10 +15,11 @@ from About import About
 ###########################################################################################
 class Coffee:
 	def __init__(self):
-		self.Windows = Windows(self)
 		self.About = About(self)
 		self.Communicate = Communicate(self)
-		self.Windows.draw("", "main")
+		self.Communicate.start()
+		self.Windows = Windows(self)
+		self.Windows.start()
 
 	def quit(self, ignore1, ignore2):
 		gtk.main_quit()
